import matplotlib.pyplot as plt


def get_plot(Ox, Oy):
    plt.plot(Ox, Oy)
    return plt.show()


__version__ = "1.0.5"
